//标准化输入
/**
 * analysisExcelDataOfObject  将excel解出来的数据块按需求解析成可用数据
 * @param dataList excel解出来的数据
 * @param isJumpTitle 是否跳过解析表头
 * @param keyInX key是否横向排列
 * @returns 返回 {"数据标题":数据对象 }
 */
export function analysisExcelDataOfObject(dataList, isJumpTitle?, keyInX?) {
    let result = {};
    if (keyInX) {
        let keyList = dataList[0];
        let valueList = dataList[1];
        let i = isJumpTitle ? 1:0;
        for (; i < keyList.length; i++) {
            let key = keyList[i];
            let value = valueList[i] || null;
            result[key] = value;
        }
    } else {
        let y = isJumpTitle ? 1: 0;
        for (; y < dataList.length; y++) {
            let childList = dataList[y];
            let key = childList[0];
            let value = childList[1] || null;
            result[key] = value;
        }
    }
    return result;
}


export function analysisExcelDataTime(dataList, isJumpTitle?, keyInX?) {
    const HOURS = new Date().getHours() + 1;//获取当前时间
    
    let result = {};
    if (keyInX) {
        let keyList = dataList[0];
        let valueList = dataList[1];
        let i = isJumpTitle ? 1:0;
        for (; i < keyList.length; i++) {
            let key = keyList[i];
            let value = valueList[i] || null;
            result[key] = value;
        }
    } else {
        let y = isJumpTitle ? 1: 0;
        for (; y <= HOURS; y++) {
            let childList = dataList[y];
            let key = childList[0];
            let value = childList[1] || null;
            result[key] = value;
        }
    }
    return result;
}

/**
 * analysisExcelDataOfMoreObject  将excel解出来的数据块按需求解析成可用数据
 * @param dataList excel解出来的数据
 * @param isJumpTitle 是否跳过解析表头
 * @param headerInx 第一个表头数据是否横向排列
 * @returns 返回 {"第一个表头数据":{"表头数据":值...} }
 */
 export function analysisExcelDataOfMoreObject(dataList, headerInx?) {
    let result = {};
    let titleList = dataList[0];
    if (!headerInx) {
        for (let y =1; y < dataList.length; y++) {
            let dataTitle = dataList[y][0];
            let thisData = {};
            for (let x = 1; x < dataList[y].length; x++) {
                let key = titleList[x];
                thisData[key] = dataList[y][x];
            }
            result[dataTitle] = thisData;
        }
    } else {
        let indexKeyMap = {};
        titleList.forEach((thisTitle, index) => {
            if (!index) return;
            indexKeyMap[index] = thisTitle;
            result[thisTitle] = {};
        });

        for (let y =1; y < dataList.length; y++) {
            let thisKey = dataList[y][0];
            for (let x = 1; x < dataList[y].length; x++) {
                let thisTitle = indexKeyMap[x];
                result[thisTitle][thisKey] = dataList[y][x];
            }
           
        }
    }
    return result;
}

/**
 * analysisExcelDataOfList  将excel解出来的数据块按需求解析成可用数据
 * @param dataList excel解出来的数据
 * @param keyObject 对应关系 {dataList表头名称: 英文}
 * @param headerInx 第一个表头数据是否横向排列
 * @returns 返回 {"第一个表头数据":{"表头数据":值...} }
 */
 export function analysisExcelDataOfList(dataList, keyObject, headerInx?) {
    let result = [];
    if (!headerInx) {//在y轴上排列

        let titleList = dataList[0];
        let indexKeyNameMap = {};
        titleList.forEach( (info, index) => {
            indexKeyNameMap[index + 1] = info;
        });

        for (let i = 1; i < dataList.length; i++) {
            let onceInfo = {};
            let subList = dataList[i];
            subList.forEach( (info, index) => {
                let key = indexKeyNameMap[index + 1];
                let checkKey = keyObject[key];
                onceInfo[checkKey] = info;
            });
            result.push(onceInfo);
        }
       

       
    } else {//在x轴上排列
        let indexKeyNameMap = {};
        dataList.forEach( (info, index) => {
            indexKeyNameMap[index + 1] = info[0];
        });
        let dataMap = {};

        for(let y = 0; y < dataList.length; y++) {
            let xList = dataList[y];
            for (let x = 1; x < xList.length; x++) {
                if (!dataMap[x]) dataMap[x] = {};
                let key = indexKeyNameMap[y + 1];
                let checkKey = keyObject[key];
                dataMap[x][checkKey] = xList[x];
            }
        }

        result = Object.values(dataMap);
        
    }
    return result;
}

export function analysisExcelDataOfStringList(dataList) {
    let result = [];
    for (let i = 0; i < dataList.length; i++) {
        if (!i) continue;
        let subList = dataList[i];
        result.push(subList[1]);
    }
    return result;
}
